
***
<h1 align="center">Crypto exchanges API/WSS wrapper and grpc powered server</h1>

<h2 align="center">Binance, FTX</h2>

<h3 align="center">For SPOT market</h2>

***

***

## Install

To install the library, you can just run the following command:

```console
pip install exchanges-wrapper
```

## Features
- Covers general endpoints (test connectivity and get exchange information's)
- Covers market data endpoints
- Covers Account endpoints (create and manage orders)
- Covers user data stream (receive real time user updates)
- Covers web socket streams (receive real time market updates)
- Async support
- Completely free and without limitations


## FTX Implementation Features

## Get started
- [exchanges_client.py]()

## Donate

*BNB*, *BUSD*, *USDT* (BEP20) 0x5b52c6ba862b11318616ee6cef64388618318b92

*USDT* (TRC20) TP1Y43dpY7rrRyTSLaSKDZmFirqvRcpopC

## Powered by exchanges-wrapper
### [martin-binance](https://github.com/DogsTailFarmer/martin-binance)
Free trading system for Binance and FTX SPOT markets. Adaptive customizable reverse grid strategy based on martingale.